Explanations
------------

Automated Fiber Quantification
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Tractography based on diffusion weighted MRI (dMRI) is used to find the major
white matter fascicles (tracts) in the living human brain. The health of these
tracts is an important factor underlying many cognitive and neurological
disorders.

Tissue properties may vary systematically along each tract: different
populations of axons enter and exit the tract, and disease can strike at local
positions within the tract. Because of this, quantifying and understanding
diffusion measures along each fiber tract (the tract profile) may reveal new
insights into white matter development, function, and disease that are not
obvious from mean measures of that tract ([Yeatman2012]_).


`pyAFQ` is a software package focused on automated delineation of the major
fiber tracts in individual human brains, and quantification of the tissue
properties within the tracts. To learn more about the software please refer to the Table of Contents.

For further statistical analysis of pyAFQ results, see `AFQ-Insight <https://github.com/richford/AFQ-Insight>`_ .

.. toctree::
    :maxdepth: 2

    tractometry_pipeline
    bundle_orientation